@@ -1,56 +1,39 @@
 # -*- coding: utf-8 -*-
 import json
-import reversion
-from reversion_compare.views import HistoryCompareDetailView
-from reversion.models import Version
 
-from django.shortcuts import render, redirect, get_object_or_404
-from django.urls import reverse_lazy
+import reversion
+from django.conf import settings
 from django.contrib.auth.decorators import login_required, user_passes_test
 from django.contrib.auth.mixins import UserPassesTestMixin
-from django.core.exceptions import FieldError
-from django.utils.decorators import method_decorator
-from django.urls import reverse
-from django.views.generic.edit import DeleteView
-from django.views import generic
-from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.http import HttpResponse
 from django.http import HttpResponseRedirect
-from django.db.models import Q
-from django_tables2 import SingleTableView
+from django.shortcuts import render, redirect, get_object_or_404
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django_tables2 import RequestConfig
+from django_tables2 import SingleTableView
 from django_tables2.export.views import ExportMixin
+from reversion_compare.views import HistoryCompareDetailView
 
-from apis_core.helper_functions.utils import access_for_all
-
-from .models import Person, Place, Institution, Event, Work
-from apis_core.apis_vocabularies.models import LabelType
-from apis_core.apis_metainfo.models import Uri, UriCandidate, TempEntityClass, Text
+from apis_core.apis_metainfo.models import Uri, UriCandidate, Text
+from apis_core.apis_relations.models import AbstractRelation
+from apis_core.helper_functions.RDFParser import RDFParser
 from apis_core.helper_functions.stanbolQueries import retrieve_obj
-from apis_core.helper_functions.RDFparsers import GenericRDFParser
 from apis_core.helper_functions.utils import (
     access_for_all, access_for_all_function, ENTITIES_DEFAULT_COLS
 )
-from apis_core.apis_labels.models import Label
-
+from .filters import get_list_filter_of_entity
 from .forms import (
-    FullTextForm, SearchForm, GenericFilterFormHelper,
+    GenericFilterFormHelper,
     NetworkVizFilterForm, PersonResolveUriForm,
-    get_entities_form, GenericEntitiesStanbolForm
+    GenericEntitiesStanbolForm
 )
-from .tables import (
-    PersonTable, PlaceTable, InstitutionTable, EventTable, WorkTable,
-    get_entities_table
-)
-from .filters import (
-    PersonListFilter, PlaceListFilter, InstitutionListFilter, EventListFilter, WorkListFilter,
-    get_generic_list_filter
-)
-
+from .models import Place
+from .tables import get_entities_table
 
 if 'apis_highlighter' in settings.INSTALLED_APPS:
-    from apis_highlighter.forms import SelectAnnotationProject, SelectAnnotatorAgreement
+    from apis_highlighter.forms import SelectAnnotationProject
     from apis_core.helper_functions.highlighter import highlight_text
 
 if 'charts' in settings.INSTALLED_APPS:
@@ -143,7 +126,7 @@ class GenericListViewNew(UserPassesTestMixin, ExportMixin, SingleTableView):
         qs = ContentType.objects.get(
             app_label__startswith='apis_', model=self.entity.lower()
         ).model_class().objects.all()
-        self.filter = get_generic_list_filter(self.entity.title())(self.request.GET, queryset=qs)
+        self.filter = get_list_filter_of_entity(self.entity.title())(self.request.GET, queryset=qs)
         self.filter.form.helper = self.formhelper_class()
         return self.filter.qs
 
@@ -243,7 +226,6 @@ class GenericListViewNew(UserPassesTestMixin, ExportMixin, SingleTableView):
             response = HttpResponse(content_type='text/csv')
             if context['conf_items']:
                 conf_items = context['conf_items']
-                print(dir(self))
                 try:
                     df = pd.DataFrame(
                         list(
@@ -282,7 +264,8 @@ class GenericListViewNew(UserPassesTestMixin, ExportMixin, SingleTableView):
 ############################################################################
 ############################################################################
 
-@login_required
+
+@user_passes_test(access_for_all_function)
 def getGeoJson(request):
     '''Used to retrieve GeoJsons for single objects'''
     # if request.is_ajax():
@@ -343,11 +326,11 @@ def getGeoJson(request):
     return HttpResponse(json.dumps(lst_json), content_type='application/json')
 
 
-@login_required
+@user_passes_test(access_for_all_function)
 def getGeoJsonList(request):
     '''Used to retrieve a list of GeoJsons. To generate the list the kind of connection
     and the connected entity is needed'''
-    relation = ContentType.objects.get(app_label='apis_relations', model=request.GET.get("relation")).model_class()
+    relation = AbstractRelation.get_relation_class_of_name(request.GET.get("relation"))
     #relation_type = request.GET.get("relation_type")
     objects = relation.objects.filter(
             related_place__status='distinct').select_related('related_person', 'related_place', 'relation_type')
@@ -370,10 +353,10 @@ def getGeoJsonList(request):
     return HttpResponse(json.dumps(lst_json), content_type='application/json')
 
 
-@login_required
+@user_passes_test(access_for_all_function)
 def getNetJsonList(request):
     '''Used to retrieve a Json to draw a network'''
-    relation = ContentType.objects.get(app_label='apis_relations', model='PersonPlace').model_class()
+    relation = AbstractRelation.get_relation_class_of_name('PersonPlace')
     objects = relation.objects.filter(
             related_place__status='distinct')
     nodes = dict()
@@ -408,10 +391,10 @@ def getNetJsonList(request):
     return HttpResponse(json.dumps(lst_json), content_type='application/json')
 
 
-@login_required
+@user_passes_test(access_for_all_function)
 def getNetJsonListInstitution(request):
     '''Used to retrieve a Json to draw a network'''
-    relation = ContentType.objects.get(app_label='apis_relations', model='PersonInstitution').model_class()
+    relation = AbstractRelation.get_relation_class_of_name('PersonInstitution')
     objects = relation.objects.all()
     nodes = dict()
     edges = []
@@ -451,7 +434,8 @@ def resolve_ambigue_place(request, pk, uri):
     with reversion.create_revision():
         uri = 'http://'+uri
         entity = Place.objects.get(pk=pk)
-        pl_n = GenericRDFParser(uri, kind='Place')
+        pl_n = RDFParser(uri, kind='Place')
+        pl_n.create_objct()
         pl_n_1 = pl_n.save()
         pl_n_1 = pl_n.merge(entity)
         url = pl_n_1.get_absolute_url()
@@ -471,8 +455,6 @@ def resolve_ambigue_person(request):
     if form.is_valid():
         pers = form.save()
         return redirect(reverse('apis_entities:person_edit', kwargs={'pk': pers.pk}))
-    else:
-        print(form)
 
 
 ############################################################################
@@ -483,22 +465,22 @@ def resolve_ambigue_person(request):
 ############################################################################
 ############################################################################
 
-@login_required
+@user_passes_test(access_for_all_function)
 def birth_death_map(request):
     return render(request, 'apis_entities/map_list.html')
 
 
-@login_required
+@user_passes_test(access_for_all_function)
 def pers_place_netw(request):
     return render(request, 'apis_entities/network.html')
 
 
-@login_required
+@user_passes_test(access_for_all_function)
 def pers_inst_netw(request):
     return render(request, 'apis_entities/network_institution.html')
 
 
-@login_required
+@user_passes_test(access_for_all_function)
 def generic_network_viz(request):
     if request.method == 'GET':
         form = NetworkVizFilterForm()
